/* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */

#ifndef LUA_CONFIG_H
#define LUA_CONFIG_H

// set to 0 to switch to 0-based weapon
// indices in LuaSynced** API functions
#define LUA_WEAPON_BASE_INDEX 1

// starting index for command descriptions
#define CMD_INDEX_OFFSET 1

#endif // LUA_CONFIG_H
